summaryrefslogtreecommitdiffstats
path: root/generic/tkImgPhoto.h
diff options
context:
space:
mode:
Diffstat (limited to 'generic/tkImgPhoto.h')
-rw-r--r--generic/tkImgPhoto.h32
1 files changed, 13 insertions, 19 deletions
diff --git a/generic/tkImgPhoto.h b/generic/tkImgPhoto.h
index a84ebb3..d7283b3 100644
--- a/generic/tkImgPhoto.h
+++ b/generic/tkImgPhoto.h
@@ -27,10 +27,11 @@
* Forward declarations of the structures we define.
*/
+#define PhotoMaster PhotoModel
typedef struct ColorTableId ColorTableId;
typedef struct ColorTable ColorTable;
typedef struct PhotoInstance PhotoInstance;
-typedef struct PhotoMaster PhotoMaster;
+typedef struct PhotoModel PhotoModel;
/*
* A signed 8-bit integral type. If chars are unsigned and the compiler isn't
@@ -49,13 +50,6 @@ typedef struct PhotoMaster PhotoMaster;
#endif
/*
- * An unsigned 32-bit integral type, used for pixel values. We use int rather
- * than long here to accommodate those systems where longs are 64 bits.
- */
-
-typedef unsigned int pixel;
-
-/*
* The maximum number of pixels to transmit to the server in a single
* XPutImage call.
*/
@@ -109,10 +103,10 @@ struct ColorTable {
XVisualInfo visualInfo; /* Information about the visual for windows
* using this color table. */
- pixel redValues[256]; /* Maps 8-bit values of red intensity to a
+ unsigned redValues[256]; /* Maps 8-bit values of red intensity to a
* pixel value or index in pixelMap. */
- pixel greenValues[256]; /* Ditto for green intensity. */
- pixel blueValues[256]; /* Ditto for blue intensity. */
+ unsigned greenValues[256]; /* Ditto for green intensity. */
+ unsigned blueValues[256]; /* Ditto for blue intensity. */
unsigned long *pixelMap; /* Actual pixel values allocated. */
unsigned char colorQuant[3][256];
@@ -144,11 +138,11 @@ struct ColorTable {
#define MAP_COLORS 8
/*
* Definition of the data associated with each photo image master.
*/
-struct PhotoMaster {
- Tk_ImageMaster tkMaster; /* Tk's token for image master. NULL means the
+struct PhotoModel {
+ Tk_ImageModel tkModel; /* Tk's token for image model. NULL means the
* image is being deleted. */
Tcl_Interp *interp; /* Interpreter associated with the application
* using this image. */
@@ -171,11 +165,11 @@ struct PhotoMaster {
TkRegion validRegion; /* Tk region indicating which parts of the
* image have valid image data. */
PhotoInstance *instancePtr; /* First in the list of instances associated
- * with this master. */
+ * with this model. */
};
/*
* Bit definitions for the flags field of a PhotoMaster.
* COLOR_IMAGE: 1 means that the image has different color
* components.
* IMAGE_CHANGED: 1 means that the instances of this image need
@@ -202,12 +196,12 @@ struct PhotoMaster {
*/
struct PhotoInstance {
- PhotoMaster *masterPtr; /* Pointer to master for image. */
+ PhotoModel *modelPtr; /* Pointer to model for image. */
Display *display; /* Display for windows using this instance. */
Colormap colormap; /* The image may only be used in windows with
* this particular colormap. */
PhotoInstance *nextPtr; /* Pointer to the next instance in the list of
* instances associated with this master. */
#if TCL_MAJOR_VERSION > 8
size_t refCount; /* Number of instances using this structure. */
#else
@@ -216,7 +210,7 @@ struct PhotoInstance {
Tk_Uid palette; /* Palette for these particular instances. */
double gamma; /* Gamma value for these instances. */
Tk_Uid defaultPalette; /* Default palette to use if a palette is not
* specified for the master. */
ColorTable *colorTablePtr; /* Pointer to information about colors
* allocated for image display in windows like
* this one. */
@@ -144,11 +138,11 @@ struct ColorTable {
#define MAP_COLORS 8
/*
- * Definition of the data associated with each photo image master.
+ * Definition of the data associated with each photo image model.
*/
@@ -171,11 +165,11 @@ struct PhotoMaster {
};
/*
- * Bit definitions for the flags field of a PhotoMaster.
+ * Bit definitions for the flags field of a PhotoModel.
* COLOR_IMAGE: 1 means that the image has different color
* components.
@@ -202,12 +196,12 @@ struct PhotoMaster {
* this particular colormap. */
PhotoInstance *nextPtr; /* Pointer to the next instance in the list of
- * instances associated with this master. */
+ * instances associated with this model. */
#if TCL_MAJOR_VERSION > 8
size_t refCount; /* Number of instances using this structure. */
@@ -216,7 +210,7 @@ struct PhotoInstance {
double gamma; /* Gamma value for these instances. */
Tk_Uid defaultPalette; /* Default palette to use if a palette is not
- * specified for the master. */
+ * specified for the model. */
ColorTable *colorTablePtr; /* Pointer to information about colors
* allocated for image display in windows like